@@ -19,13 +19,15 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-import os, re
+import os
+import re
 import tempfile
 
 import duplicity.backend
 from duplicity.errors import InvalidBackendURL
 from duplicity import globals, tempdir, util
 
+
 class RsyncBackend(duplicity.backend.Backend):
     """Connect to remote store using rsync
 
@@ -104,7 +106,7 @@ class RsyncBackend(duplicity.backend.Backend):
         if m:
             return m.group(2), m.group(1).lstrip(':')
         raise InvalidBackendURL("Could not determine rsync path: %s"
-                                    "" % self.munge_password(url))
+                                "" % self.munge_password(url))
 
     def _put(self, source_path, remote_filename):
         remote_path = os.path.join(self.url_string, remote_filename)
@@ -146,12 +148,12 @@ class RsyncBackend(duplicity.backend.Backend):
             print >> exclude, file
             f.close()
         exclude.close()
-        commandline = ("%s --recursive --delete --exclude-from=%s %s/ %s" % 
-                                   (self.cmd, exclude_name, dir, self.url_string))
+        commandline = ("%s --recursive --delete --exclude-from=%s %s/ %s" %
+                       (self.cmd, exclude_name, dir, self.url_string))
         self.subprocess_popen(commandline)
         for file in to_delete:
             util.ignore_missing(os.unlink, file)
         os.rmdir(dir)
 
 duplicity.backend.register_backend("rsync", RsyncBackend)
-duplicity.backend.uses_netloc.extend([ 'rsync' ])
+duplicity.backend.uses_netloc.extend(['rsync'])
