@@ -29,7 +29,9 @@ the second, the ROPath iterator is put into tar block form.
 
 from future_builtins import map
 
-import cStringIO, types, math
+import cStringIO
+import types
+import math
 from duplicity import statistics
 from duplicity import util
 from duplicity import globals
@@ -41,6 +43,7 @@ from duplicity import progress
 stats = None
 tracker = None
 
+
 class DiffDirException(Exception):
     pass
 
@@ -80,7 +83,7 @@ def DirDelta(path_iter, dirsig_fileobj_list):
     """
     global stats
     stats = statistics.StatsDeltaProcess()
-    if type(dirsig_fileobj_list) is types.ListType:
+    if isinstance(dirsig_fileobj_list, types.ListType):
         sig_iter = combine_path_iters([sigtar2path_iter(x) for x
                                        in dirsig_fileobj_list])
     else:
@@ -161,14 +164,14 @@ def log_delta_path(delta_path, new_path=None, stats=None):
     if delta_path.difftype == "snapshot":
         if new_path and stats:
             stats.add_new_file(new_path)
-        log.Info(_("A %s") % 
+        log.Info(_("A %s") %
                  (util.ufn(delta_path.get_relative_path())),
                  log.InfoCode.diff_file_new,
                  util.escape(delta_path.get_relative_path()))
     else:
         if new_path and stats:
             stats.add_changed_file(new_path)
-        log.Info(_("M %s") % 
+        log.Info(_("M %s") %
                  (util.ufn(delta_path.get_relative_path())),
                  log.InfoCode.diff_file_changed,
                  util.escape(delta_path.get_relative_path()))
@@ -198,7 +201,7 @@ def get_delta_iter(new_iter, sig_iter, sig_fileobj=None):
             # such a way as to fool us; LP: #929067)
             if sig_path and sig_path.exists() and sig_path.index != ():
                 # but signature says it did
-                log.Info(_("D %s") % 
+                log.Info(_("D %s") %
                          (util.ufn(sig_path.get_relative_path())),
                          log.InfoCode.diff_file_deleted,
                          util.escape(sig_path.get_relative_path()))
@@ -206,7 +209,7 @@ def get_delta_iter(new_iter, sig_iter, sig_fileobj=None):
                     ti = ROPath(sig_path.index).get_tarinfo()
                     ti.name = "deleted/" + "/".join(sig_path.index)
                     sigTarFile.addfile(ti)
-                stats.add_deleted_file()
+                stats.add_deleted_file(sig_path)
                 yield ROPath(sig_path.index)
         elif not sig_path or new_path != sig_path:
             # Must calculate new signature and create delta
@@ -361,7 +364,7 @@ def DirDelta_WriteSig(path_iter, sig_infp_list, newsig_outfp):
     """
     global stats
     stats = statistics.StatsDeltaProcess()
-    if type(sig_infp_list) is types.ListType:
+    if isinstance(sig_infp_list, types.ListType):
         sig_path_iter = get_combined_path_iter(sig_infp_list)
     else:
         sig_path_iter = sigtar2path_iter(sig_infp_list)
@@ -406,6 +409,7 @@ class FileWithSignature:
     File-like object which also computes signature as it is read
     """
     blocksize = 32 * 1024
+
     def __init__(self, infile, callback, filelen, *extra_args):
         """
         FileTee initializer
@@ -713,7 +717,7 @@ def write_block_iter(block_iter, out_obj):
     """
     if isinstance(out_obj, Path):
         fp = open(out_obj.name, "wb")
-    elif type(out_obj) is types.StringType:
+    elif isinstance(out_obj, types.StringType):
         fp = open(out_obj, "wb")
     else:
         fp = out_obj
