@@ -38,6 +38,7 @@ full_sig_re_short = None
 new_sig_re = None
 new_sig_re_short = None
 
+
 def prepare_regex(force=False):
     global full_vol_re
     global full_vol_re_short
@@ -57,86 +58,86 @@ def prepare_regex(force=False):
         return
 
     full_vol_re = re.compile("^" + globals.file_prefix + globals.file_prefix_archive + "duplicity-full"
-                         "\\.(?P<time>.*?)"
-                         "\\.vol(?P<num>[0-9]+)"
-                         "\\.difftar"
-                         "(?P<partial>(\\.part))?"
-                         "($|\\.)")
+                             "\\.(?P<time>.*?)"
+                             "\\.vol(?P<num>[0-9]+)"
+                             "\\.difftar"
+                             "(?P<partial>(\\.part))?"
+                             "($|\\.)")
 
     full_vol_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_archive + "df"
-                               "\\.(?P<time>[0-9a-z]+?)"
-                               "\\.(?P<num>[0-9a-z]+)"
-                               "\\.dt"
-                               "(?P<partial>(\\.p))?"
-                               "($|\\.)")
+                                   "\\.(?P<time>[0-9a-z]+?)"
+                                   "\\.(?P<num>[0-9a-z]+)"
+                                   "\\.dt"
+                                   "(?P<partial>(\\.p))?"
+                                   "($|\\.)")
 
     full_manifest_re = re.compile("^" + globals.file_prefix + globals.file_prefix_manifest + "duplicity-full"
-                              "\\.(?P<time>.*?)"
-                              "\\.manifest"
-                              "(?P<partial>(\\.part))?"
-                              "($|\\.)")
+                                  "\\.(?P<time>.*?)"
+                                  "\\.manifest"
+                                  "(?P<partial>(\\.part))?"
+                                  "($|\\.)")
 
     full_manifest_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_manifest + "df"
-                                    "\\.(?P<time>[0-9a-z]+?)"
-                                    "\\.m"
-                                    "(?P<partial>(\\.p))?"
-                                    "($|\\.)")
+                                        "\\.(?P<time>[0-9a-z]+?)"
+                                        "\\.m"
+                                        "(?P<partial>(\\.p))?"
+                                        "($|\\.)")
 
     inc_vol_re = re.compile("^" + globals.file_prefix + globals.file_prefix_archive + "duplicity-inc"
-                        "\\.(?P<start_time>.*?)"
-                        "\\.to\\.(?P<end_time>.*?)"
-                        "\\.vol(?P<num>[0-9]+)"
-                        "\\.difftar"
-                        "($|\\.)")
+                            "\\.(?P<start_time>.*?)"
+                            "\\.to\\.(?P<end_time>.*?)"
+                            "\\.vol(?P<num>[0-9]+)"
+                            "\\.difftar"
+                            "($|\\.)")
 
     inc_vol_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_archive + "di"
-                              "\\.(?P<start_time>[0-9a-z]+?)"
-                              "\\.(?P<end_time>[0-9a-z]+?)"
-                              "\\.(?P<num>[0-9a-z]+)"
-                              "\\.dt"
-                              "($|\\.)")
+                                  "\\.(?P<start_time>[0-9a-z]+?)"
+                                  "\\.(?P<end_time>[0-9a-z]+?)"
+                                  "\\.(?P<num>[0-9a-z]+)"
+                                  "\\.dt"
+                                  "($|\\.)")
 
     inc_manifest_re = re.compile("^" + globals.file_prefix + globals.file_prefix_manifest + "duplicity-inc"
-                             "\\.(?P<start_time>.*?)"
-                             "\\.to"
-                             "\\.(?P<end_time>.*?)"
-                             "\\.manifest"
+                                 "\\.(?P<start_time>.*?)"
+                                 "\\.to"
+                                 "\\.(?P<end_time>.*?)"
+                                 "\\.manifest"
+                                 "(?P<partial>(\\.part))?"
+                                 "(\\.|$)")
+
+    inc_manifest_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_manifest + "di"
+                                       "\\.(?P<start_time>[0-9a-z]+?)"
+                                       "\\.(?P<end_time>[0-9a-z]+?)"
+                                       "\\.m"
+                                       "(?P<partial>(\\.p))?"
+                                       "(\\.|$)")
+
+    full_sig_re = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "duplicity-full-signatures"
+                             "\\.(?P<time>.*?)"
+                             "\\.sigtar"
                              "(?P<partial>(\\.part))?"
                              "(\\.|$)")
 
-    inc_manifest_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_manifest + "di"
-                                   "\\.(?P<start_time>[0-9a-z]+?)"
-                                   "\\.(?P<end_time>[0-9a-z]+?)"
-                                   "\\.m"
+    full_sig_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "dfs"
+                                   "\\.(?P<time>[0-9a-z]+?)"
+                                   "\\.st"
                                    "(?P<partial>(\\.p))?"
                                    "(\\.|$)")
 
-    full_sig_re = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "duplicity-full-signatures"
-                         "\\.(?P<time>.*?)"
-                         "\\.sigtar"
-                         "(?P<partial>(\\.part))?"
-                         "(\\.|$)")
-
-    full_sig_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "dfs"
-                               "\\.(?P<time>[0-9a-z]+?)"
-                               "\\.st"
-                               "(?P<partial>(\\.p))?"
-                               "(\\.|$)")
-
     new_sig_re = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "duplicity-new-signatures"
-                        "\\.(?P<start_time>.*?)"
-                        "\\.to"
-                        "\\.(?P<end_time>.*?)"
-                        "\\.sigtar"
-                        "(?P<partial>(\\.part))?"
-                        "(\\.|$)")
+                            "\\.(?P<start_time>.*?)"
+                            "\\.to"
+                            "\\.(?P<end_time>.*?)"
+                            "\\.sigtar"
+                            "(?P<partial>(\\.part))?"
+                            "(\\.|$)")
 
     new_sig_re_short = re.compile("^" + globals.file_prefix + globals.file_prefix_signature + "dns"
-                              "\\.(?P<start_time>[0-9a-z]+?)"
-                              "\\.(?P<end_time>[0-9a-z]+?)"
-                              "\\.st"
-                              "(?P<partial>(\\.p))?"
-                              "(\\.|$)")
+                                  "\\.(?P<start_time>[0-9a-z]+?)"
+                                  "\\.(?P<end_time>[0-9a-z]+?)"
+                                  "\\.st"
+                                  "(?P<partial>(\\.p))?"
+                                  "(\\.|$)")
 
 
 def to_base36(n):
@@ -219,26 +220,26 @@ def get(type, volume_number=None, manifest=False,
         assert not (volume_number and part_string)
         if type == "full-sig":
             if globals.short_filenames:
-                return (globals.file_prefix + globals.file_prefix_signature + "dfs.%s.st%s%s" % 
+                return (globals.file_prefix + globals.file_prefix_signature + "dfs.%s.st%s%s" %
                         (to_base36(dup_time.curtime), part_string, suffix))
             else:
-                return (globals.file_prefix + globals.file_prefix_signature + "duplicity-full-signatures.%s.sigtar%s%s" % 
+                return (globals.file_prefix + globals.file_prefix_signature + "duplicity-full-signatures.%s.sigtar%s%s" %
                         (dup_time.curtimestr, part_string, suffix))
         elif type == "new-sig":
             if globals.short_filenames:
-                return (globals.file_prefix + globals.file_prefix_signature + "dns.%s.%s.st%s%s" % 
+                return (globals.file_prefix + globals.file_prefix_signature + "dns.%s.%s.st%s%s" %
                         (to_base36(dup_time.prevtime), to_base36(dup_time.curtime),
                          part_string, suffix))
             else:
-                return (globals.file_prefix + globals.file_prefix_signature + "duplicity-new-signatures.%s.to.%s.sigtar%s%s" % 
+                return (globals.file_prefix + globals.file_prefix_signature + "duplicity-new-signatures.%s.to.%s.sigtar%s%s" %
                         (dup_time.prevtimestr, dup_time.curtimestr,
                          part_string, suffix))
     else:
         assert volume_number or manifest
         assert not (volume_number and manifest)
-            
+
         prefix = globals.file_prefix
-        
+
         if volume_number:
             if globals.short_filenames:
                 vol_string = "%s.dt" % to_base36(volume_number)
@@ -251,23 +252,23 @@ def get(type, volume_number=None, manifest=False,
             else:
                 vol_string = "manifest"
             prefix += globals.file_prefix_manifest
-            
+
         if type == "full":
             if globals.short_filenames:
                 return ("%sdf.%s.%s%s%s" % (prefix, to_base36(dup_time.curtime),
-                                          vol_string, part_string, suffix))
+                                            vol_string, part_string, suffix))
             else:
                 return ("%sduplicity-full.%s.%s%s%s" % (prefix, dup_time.curtimestr,
-                                                      vol_string, part_string, suffix))
+                                                        vol_string, part_string, suffix))
         elif type == "inc":
             if globals.short_filenames:
                 return ("%sdi.%s.%s.%s%s%s" % (prefix, to_base36(dup_time.prevtime),
-                                             to_base36(dup_time.curtime),
-                                             vol_string, part_string, suffix))
+                                               to_base36(dup_time.curtime),
+                                               vol_string, part_string, suffix))
             else:
                 return ("%sduplicity-inc.%s.to.%s.%s%s%s" % (prefix, dup_time.prevtimestr,
-                                                           dup_time.curtimestr,
-                                                           vol_string, part_string, suffix))
+                                                             dup_time.curtimestr,
+                                                             vol_string, part_string, suffix))
         else:
             assert 0
 
@@ -277,6 +278,7 @@ def parse(filename):
     Parse duplicity filename, return None or ParseResults object
     """
     filename = filename.lower()
+
     def str2time(timestr, short):
         """
         Return time in seconds if string can be converted, None otherwise
@@ -319,7 +321,7 @@ def parse(filename):
                                         volume_number=get_vol_num(m1.group("num"), short))
                 else:
                     return ParseResults("full", time=t, manifest=True,
-                                        partial=(m2.group("partial") != None))
+                                        partial=(m2.group("partial") is not None))
         return None
 
     def check_inc():
@@ -343,7 +345,7 @@ def parse(filename):
                                         end_time=t2, volume_number=get_vol_num(m1.group("num"), short))
                 else:
                     return ParseResults("inc", start_time=t1, end_time=t2, manifest=1,
-                                        partial=(m2.group("partial") != None))
+                                        partial=(m2.group("partial") is not None))
         return None
 
     def check_sig():
@@ -360,7 +362,7 @@ def parse(filename):
             t = str2time(m.group("time"), short)
             if t:
                 return ParseResults("full-sig", time=t,
-                                    partial=(m.group("partial") != None))
+                                    partial=(m.group("partial") is not None))
             else:
                 return None
 
@@ -374,7 +376,7 @@ def parse(filename):
             t2 = str2time(m.group("end_time"), short)
             if t1 and t2:
                 return ParseResults("new-sig", start_time=t1, end_time=t2,
-                                    partial=(m.group("partial") != None))
+                                    partial=(m.group("partial") is not None))
         return None
 
     def set_encryption_or_compression(pr):
