@@ -31,13 +31,14 @@ import sys
 import string
 import traceback
 
-from lockfile import FileLock, UnlockError
+from lockfile import UnlockError
 
 from duplicity import tarfile
 
 import duplicity.globals as globals
 import duplicity.log as log
 
+
 def exception_traceback(limit=50):
     """
     @return A string representation in typical Python format of the
@@ -53,16 +54,19 @@ def exception_traceback(limit=50):
 
     return uexc(msg)
 
+
 def escape(string):
     "Convert a (bytes) filename to a format suitable for logging (quoted utf8)"
     string = ufn(string).encode('unicode-escape', 'replace')
     return u"'%s'" % string.decode('utf8', 'replace')
 
+
 def ufn(filename):
     "Convert a (bytes) filename to unicode for printing"
     assert not isinstance(filename, unicode)
     return filename.decode(sys.getfilesystemencoding(), 'replace')
 
+
 def uindex(index):
     "Convert an index (a tuple of path parts) to unicode for printing"
     if index:
@@ -70,6 +74,7 @@ def uindex(index):
     else:
         return u'.'
 
+
 def uexc(e):
     # Exceptions in duplicity often have path names in them, which if they are
     # non-ascii will cause a UnicodeDecodeError when implicitly decoding to
@@ -77,6 +82,7 @@ def uexc(e):
     # 99.99% of the time, this will be a fine encoding to use.
     return ufn(str(e))
 
+
 def maybe_ignore_errors(fn):
     """
     Execute fn. If the global configuration setting ignore_errors is
@@ -96,17 +102,23 @@ def maybe_ignore_errors(fn):
         else:
             raise
 
+
 class BlackHoleList(list):
+
     def append(self, x):
         pass
 
+
 class FakeTarFile:
     debug = 0
+
     def __iter__(self):
         return iter([])
+
     def close(self):
         pass
 
+
 def make_tarfile(mode, fp):
     # We often use 'empty' tarfiles for signatures that haven't been filled out
     # yet.  So we want to ignore ReadError exceptions, which are used to signal
@@ -121,6 +133,7 @@ def make_tarfile(mode, fp):
     except tarfile.ReadError:
         return FakeTarFile()
 
+
 def get_tarinfo_name(ti):
     # Python versions before 2.6 ensure that directories end with /, but 2.6
     # and later ensure they they *don't* have /.  ::shrug::  Internally, we
@@ -130,6 +143,7 @@ def get_tarinfo_name(ti):
     else:
         return ti.name
 
+
 def ignore_missing(fn, filename):
     """
     Execute fn on filename.  Ignore ENOENT errors, otherwise raise exception.
@@ -145,14 +159,16 @@ def ignore_missing(fn, filename):
         else:
             raise
 
+
 def release_lockfile():
     if globals.lockfile and globals.lockfile.is_locked():
-        log.Debug(_("Releasing lockfile %s") % globals.lockfile)
+        log.Debug(_("Releasing lockfile %s") % globals.lockfile.lock_file)
         try:
             globals.lockfile.release()
         except UnlockError:
             pass
 
+
 def copyfileobj(infp, outfp, byte_count=-1):
     """Copy byte_count bytes from infp to outfp, or all if byte_count < 0
 
